<?php

namespace Drupal\image_effects\Tests;

/**
 * Convolution sharpen effect test.
 *
 * @group Image Effects
 */
class ImageEffectsConvolutionSharpenTest extends ImageEffectsTestBase {

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();
    // @todo This effect does not work on GraphicsMagick.
    $this->imagemagickPackages['graphicsmagick'] = FALSE;
  }

  /**
   * Convolution sharpen effect test.
   */
  public function testConvolutionSharpenEffect() {
    // Test operations on toolkits.
    $this->executeTestOnToolkits([$this, 'doTestConvolutionSharpenOperations']);
  }

  /**
   * Convolution sharpen operations test.
   */
  public function doTestConvolutionSharpenOperations() {
    $original_uri = $this->getTestImageCopyUri('/files/image-test.png', 'simpletest');
    $derivative_uri = 'public://test-images/image-test-derived.png';

    // Add convolution sharpen effect to the test image style.
    $effect = [
      'id' => 'image_effects_convolution_sharpen',
      'data' => [
        'level' => 10,
      ],
    ];
    $uuid = $this->addEffectToTestStyle($effect);

    // Apply the operation, via the effect.
    $image = $this->imageFactory->get($original_uri);
    $effect = $this->testImageStyle->getEffect($uuid);
    $effect->applyEffect($image);

    // Toolkit-specific tests.
    switch ($this->imageFactory->getToolkitId()) {
      case 'gd':
        // For the GD toolkit, just test derivative image is valid.
        $image->save($derivative_uri);
        $derivative_image = $this->imageFactory->get($derivative_uri);
        $this->assertTrue($derivative_image->isValid());
        break;

      case 'imagemagick':
        // For the Imagemagick toolkit, check the command line argument has
        // been formatted properly.
        $argument = $image->getToolkit()->getArguments()[$image->getToolkit()->findArgument('-morphology')];
        $this->assertEqual("-morphology Convolve '3x3:-0.1,-0.1,-0.1 -0.1,1.8,-0.1 -0.1,-0.1,-0.1'", $argument);
        break;

    }

    // Remove effect.
    $this->removeEffectFromTestStyle($uuid);

  }

}
